InvertedPin

Struct InvertedPin 

pub struct InvertedPin<P> { /* private fields */ }
Inverted input/output pin

If wrapping an output pin, whenever setting this pin to a high or low level, the wrapped pin will be set to the opposite level.

Likewise, if wrapping an input pin, whenever reading this pin it will read the wrapped input pin and return the opposite level.

Implementations

Source

impl<P> InvertedPin<P>

pub fn new(pin: P) -> Self

Create new instance

pub fn destroy(self) -> P

Destroy instance and return the wrapped pin