pub struct InvertedPin<P> { /* private fields */ }Expand description
Inverted input/output pin
If wrapping an output pin, whenever setting this pin to a high or low level, the wrapped pin will be set to the opposite level.
Likewise, if wrapping an input pin, whenever reading this pin it will read the wrapped input pin and return the opposite level.
Implementations